@@ -42,6 +42,10 @@ def plot_rdm(rdm, percentile=False, rescale=False, lim=[0, 1], conditions=None,
         If cmap=None, the ccolormap will be 'jet'.
     """
 
+    if len(np.shape(rdm)) != 2 or np.shape(rdm)[0] != np.shape(rdm)[1]:
+
+        return "Invalid input!"
+
     # get the number of conditions
     cons = rdm.shape[0]
 
@@ -148,6 +152,8 @@ def plot_rdm(rdm, percentile=False, rescale=False, lim=[0, 1], conditions=None,
 
     plt.show()
 
+    return 0
+
 
 ' a function for plotting the RDM with values '
 
@@ -174,6 +180,10 @@ def plot_rdm_withvalue(rdm, lim=[0, 1], value_fontsize=10, conditions=None, con_
         If cmap=None, the ccolormap will be 'Greens'.
     """
 
+    if len(np.shape(rdm)) != 2 or np.shape(rdm)[0] != np.shape(rdm)[1]:
+
+        return "Invalid input!"
+
     # get the number of conditions
     cons = rdm.shape[0]
 
@@ -220,10 +230,10 @@ def plot_rdm_withvalue(rdm, lim=[0, 1], value_fontsize=10, conditions=None, con_
     else:
         plt.axis("off")
 
-
-
     plt.show()
 
+    return 0
+
 
 ' a function for plotting the correlation coefficients by time sequence '
 
@@ -246,6 +256,10 @@ def plot_corrs_by_time(corrs, labels=None, time_unit=[0, 0.1]):
         time_unit=[0, 0.1], which means the start time of corrs is 0 sec and the time step is 0.1 sec.
     """
 
+    if len(np.shape(corrs)) < 2 or len(np.shape(corrs)) > 3:
+
+        return "Invalid input!"
+
     # get the number of curves
     n = corrs.shape[0]
 
@@ -319,6 +333,8 @@ def plot_corrs_by_time(corrs, labels=None, time_unit=[0, 0.1]):
 
     plt.show()
 
+    return 0
+
 
 def plot_tbytsim_withstats(Similarities, start_time=0, end_time=1, color='r', lim=[-0.1, 0.8]):
 
@@ -341,6 +357,10 @@ def plot_tbytsim_withstats(Similarities, start_time=0, end_time=1, color='r', li
         The corrs view lims.
     """
 
+    if len(np.shape(Similarities)) < 2 or len(np.shape(Similarities)) > 3:
+
+        return "Invalid input!"
+
     n = len(np.shape(Similarities))
 
     minlim = lim[0]
@@ -398,6 +418,8 @@ def plot_tbytsim_withstats(Similarities, start_time=0, end_time=1, color='r', li
     plt.ylabel("Representational Similarity", fontsize=16)
     plt.show()
 
+    return 0
+
 
 ' a function for plotting the hotmap of correlations coefficients for channels/regions by time sequence '
 
@@ -430,6 +452,10 @@ def plot_corrs_hotmap(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], smo
         If cmap=None, the ccolormap will be 'inferno'.
     """
 
+    if len(np.shape(corrs)) < 2 or len(np.shape(corrs)) > 3:
+
+        return "Invalid input!"
+
     # get the number of channels
     nchls = corrs.shape[0]
 
@@ -537,6 +563,8 @@ def plot_corrs_hotmap(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], smo
 
     plt.show()
 
+    return 0
+
 
 ' a function for plotting the hotmap of correlations coefficients for channels/regions by time sequence with the significant outline '
 
@@ -578,6 +606,10 @@ def plot_corrs_hotmap_stats(corrs, stats, chllabels=None, time_unit=[0, 0.1], li
         If cmap=None, the ccolormap will be 'inferno'.
     """
 
+    if len(np.shape(corrs)) < 2 or len(np.shape(corrs)) > 3:
+
+        return "Invalid input!"
+
     # get the number of channels
     nchls = corrs.shape[0]
 
@@ -733,6 +765,8 @@ def plot_corrs_hotmap_stats(corrs, stats, chllabels=None, time_unit=[0, 0.1], li
 
     plt.show()
 
+    return 0
+
 
 ' a function for plotting the hotmap of neural pattern similarities for channels/regions by time sequence '
 
@@ -766,6 +800,10 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
         If cmap=None, the ccolormap will be 'viridis'.
     """
 
+    if len(np.shape(similarities)) != 2:
+
+        return "Invalid input!"
+
     # absolute value
     if abs == True:
         similarities = np.abs(similarities)
@@ -866,6 +904,8 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
 
     plt.show()
 
+    return 0
+
 
 ' a function for plotting the hotmap of statistical results for channels/regions by time sequence '
 
@@ -904,6 +944,10 @@ def plot_stats_hotmap(stats, chllabels=None, time_unit=[0, 0.1], lim=[-7, 7], sm
         If threshold=5, the time threshold is a window of 5 time-points for each channel/region.
     """
 
+    if len(np.shape(stats)) != 3:
+
+        return "Invalid input!"
+
     statscopy = stats.copy()
 
     # get the number of channels
@@ -1050,6 +1094,8 @@ def plot_stats_hotmap(stats, chllabels=None, time_unit=[0, 0.1], lim=[-7, 7], sm
 
     plt.show()
 
+    return 0
+
 
 ' a function for plotting the RSA-result regions by 3 cuts (frontal, axial & lateral) '
 
@@ -1072,7 +1118,7 @@ def plot_brainrsa_regions(img, threshold=None, background=get_bg_ch2(), type='r'
         The type of result (r-values or t-values).
     """
 
-    imgarray = nib.load(img).get_data()
+    imgarray = nib.load(img).get_fdata()
 
     if (imgarray == np.nan).all() == True:
         print("No Valid Results")
@@ -1080,7 +1126,7 @@ def plot_brainrsa_regions(img, threshold=None, background=get_bg_ch2(), type='r'
     else:
         if threshold != None:
 
-            imgarray = nib.load(img).get_data()
+            imgarray = nib.load(img).get_fdata()
             affine = get_affine(img)
 
             imgarray = correct_by_threshold(imgarray, threshold)
@@ -1096,6 +1142,8 @@ def plot_brainrsa_regions(img, threshold=None, background=get_bg_ch2(), type='r'
 
         plt.show()
 
+    return 0
+
 
 ' a function for plotting the RSA-result by different cuts '
 
@@ -1124,7 +1172,7 @@ def plot_brainrsa_montage(img, threshold=None, slice=[6, 6, 6], background=get_b
         The type of result (r-values or t-values).
     """
 
-    imgarray = nib.load(img).get_data()
+    imgarray = nib.load(img).get_fdata()
 
     if (imgarray == np.nan).all() == True:
 
@@ -1133,7 +1181,7 @@ def plot_brainrsa_montage(img, threshold=None, slice=[6, 6, 6], background=get_b
     else:
 
         if threshold != None:
-            imgarray = nib.load(img).get_data()
+            imgarray = nib.load(img).get_fdata()
             affine = get_affine(img)
             imgarray = correct_by_threshold(imgarray, threshold)
             img = nib.Nifti1Image(imgarray, affine)
@@ -1161,6 +1209,8 @@ def plot_brainrsa_montage(img, threshold=None, slice=[6, 6, 6], background=get_b
 
         plt.show()
 
+    return 0
+
 
 ' a function for plotting the 2-D projection of the RSA-result '
 
@@ -1181,7 +1231,7 @@ def plot_brainrsa_glass(img, threshold=None, type='r'):
         The type of result (r-values or t-values).
     """
 
-    imgarray = nib.load(img).get_data()
+    imgarray = nib.load(img).get_fdata()
 
     if (imgarray == np.nan).all() == True:
 
@@ -1190,7 +1240,7 @@ def plot_brainrsa_glass(img, threshold=None, type='r'):
     else:
         if threshold != None:
 
-            imgarray = nib.load(img).get_data()
+            imgarray = nib.load(img).get_fdata()
             affine = get_affine(img)
             imgarray = correct_by_threshold(imgarray, threshold)
             img = nib.Nifti1Image(imgarray, affine)
@@ -1202,6 +1252,8 @@ def plot_brainrsa_glass(img, threshold=None, type='r'):
 
         plt.show()
 
+    return 0
+
 
 ' a function for plotting the RSA-result into a brain surface '
 
@@ -1222,7 +1274,7 @@ def plot_brainrsa_surface(img, threshold=None, type='r'):
         The type of result (r-values or t-values).
     """
 
-    imgarray = nib.load(img).get_data()
+    imgarray = nib.load(img).get_fdata()
 
     if (imgarray == np.nan).all() == True:
 
@@ -1232,7 +1284,7 @@ def plot_brainrsa_surface(img, threshold=None, type='r'):
 
         if threshold != None:
 
-            imgarray = nib.load(img).get_data()
+            imgarray = nib.load(img).get_fdata()
             affine = get_affine(img)
             imgarray = correct_by_threshold(imgarray, threshold)
             img = nib.Nifti1Image(imgarray, affine)
@@ -1273,6 +1325,8 @@ def plot_brainrsa_surface(img, threshold=None, type='r'):
 
             plt.show()
 
+    return 0
+
 
 
 ' a function for plotting the RSA-result by a set of images '
@@ -1296,7 +1350,7 @@ def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None, ty
         The type of result (r-values or t-values).
     """
 
-    imgarray = nib.load(img).get_data()
+    imgarray = nib.load(img).get_fdata()
 
     if (imgarray == np.nan).all() == True:
         print("No Valid Results")
@@ -1304,7 +1358,7 @@ def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None, ty
 
         if threshold != None:
 
-            imgarray = nib.load(img).get_data()
+            imgarray = nib.load(img).get_fdata()
             affine = get_affine(img)
             imgarray = correct_by_threshold(imgarray, threshold)
             img = nib.Nifti1Image(imgarray, affine)
@@ -1326,3 +1380,5 @@ def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None, ty
             plot_brainrsa_montage(img, threshold=threshold, slice=slice, background=background, type=type)
 
             plot_brainrsa_surface(img, threshold=threshold, type=type)
+
+    return 0
